@@ -1,5 +1,5 @@
 /* Lzip - LZMA lossless data compressor
-   Copyright (C) 2008-2021 Antonio Diaz Diaz.
+   Copyright (C) 2008-2025 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -86,7 +86,7 @@ inline int price1( const Bit_model bm )
   { return prob_prices[bit_model_total - bm.probability]; }
 
 inline int price_bit( const Bit_model bm, const bool bit )
-  { return ( bit ? price1( bm ) : price0( bm ) ); }
+  { return bit ? price1( bm ) : price0( bm ); }
 
 
 inline int price_symbol3( const Bit_model bm[], int symbol )
@@ -238,7 +238,7 @@ class Range_encoder
     {
     if( low >> 24 != 0xFF )
       {
-      const bool carry = ( low > 0xFFFFFFFFU );
+      const bool carry = low > 0xFFFFFFFFU;
       put_byte( cache + carry );
       for( ; ff_count > 0; --ff_count ) put_byte( 0xFF + carry );
       cache = low >> 24;
@@ -260,8 +260,7 @@ public:
     ff_count = 0;
     cache = 0;
     header.dictionary_size( dictionary_size );
-    for( int i = 0; i < Lzip_header::size; ++i )
-      put_byte( header.data[i] );
+    for( int i = 0; i < header.size; ++i ) put_byte( header.data[i] );
     }
 
   Range_encoder( const unsigned dictionary_size, const int ofd )
@@ -302,7 +301,8 @@ public:
     if( !bit )
       {
       range = bound;
-      bm.probability += (bit_model_total - bm.probability) >> bit_model_move_bits;
+      bm.probability +=
+        ( bit_model_total - bm.probability ) >> bit_model_move_bits;
       }
     else
       {
@@ -378,13 +378,13 @@ public:
 
   void encode_len( Len_model & lm, int symbol, const int pos_state )
     {
-    bool bit = ( ( symbol -= min_match_len ) >= len_low_symbols );
+    bool bit = ( symbol -= min_match_len ) >= len_low_symbols;
     encode_bit( lm.choice1, bit );
     if( !bit )
       encode_tree3( lm.bm_low[pos_state], symbol );
     else
       {
-      bit = ( ( symbol -= len_low_symbols ) >= len_mid_symbols );
+      bit = ( symbol -= len_low_symbols ) >= len_mid_symbols;
       encode_bit( lm.choice2, bit );
       if( !bit )
         encode_tree3( lm.bm_mid[pos_state], symbol );
